==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/link/lang/bg.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'bg', {
	acccessKey: 'Клавиш за достъп',
	advanced: 'Разширено',
	advisoryContentType: 'Тип на съдържанието',
	advisoryTitle: 'Заглавие',
	anchor: {
		toolbar: 'Котва',
		menu: 'Промяна на котва',
		title: 'Настройки на котва',
		name: 'Име на котва',
		errorName: 'Моля въведете име на котвата',
		remove: 'Премахване на котва'
	},
	anchorId: 'По ID на елемент',
	anchorName: 'По име на котва',
	charset: 'Езиков код на свързания ресурс',
	cssClasses: 'CSS класове',
	download: 'Укажи изтегляне',
	displayText: 'Текст за показване',
	emailAddress: 'Имейл aдрес',
	emailBody: 'Съдържание',
	emailSubject: 'Тема',
	id: 'Id',
	info: 'Връзка',
	langCode: 'Езиков код',
	langDir: 'Посока на езика',
	langDirLTR: 'От ляво надясно (LTR)',
	langDirRTL: 'От дясно наляво (RTL)',
	menu: 'Промяна на връзка',
	name: 'Име',
	noAnchors: '(Няма котви в текущия документ)',
	noEmail: 'Моля въведете имейл адрес',
	noUrl: 'Моля въведете URL адрес',
	noTel: 'Please type the phone number', // MISSING
	other: '<друго>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Зависимост (Netscape)',
	popupFeatures: 'Функции на изкачащ прозорец',
	popupFullScreen: 'Цял екран (IE)',
	popupLeft: 'Лява позиция',
	popupLocationBar: 'Лента с локацията',
	popupMenuBar: 'Лента за меню',
	popupResizable: 'Оразмеряем',
	popupScrollBars: 'Ленти за прелистване',
	popupStatusBar: 'Статусна лента',
	popupToolbar: 'Лента с инструменти',
	popupTop: 'Горна позиция',
	rel: 'Свързаност (rel атрибут)',
	selectAnchor: 'Изберете котва',
	styles: 'Стил',
	tabIndex: 'Ред на достъп',
	target: 'Цел',
	targetFrame: '<frame>',
	targetFrameName: 'Име на целевия прозорец',
	targetPopup: '<изкачащ прозорец>',
	targetPopupName: 'Име на изкачащ прозорец',
	title: 'Връзка',
	toAnchor: 'Връзка към котва в текста',
	toEmail: 'Имейл',
	toUrl: 'Уеб адрес',
	toPhone: 'Phone', // MISSING
	toolbar: 'Връзка',
	type: 'Тип на връзката',
	unlink: 'Премахни връзката',
	upload: 'Качване'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/bg.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'bg', {
	acccessKey: 'Клавиш за достъп',
	advanced: 'Разширено',
	advisoryContentType: 'Тип на съдържанието',
	advisoryTitle: 'Заглавие',
	anchor: {
		toolbar: 'Котва',
		menu: 'Промяна на котва',
		title: 'Настройки на котва',
		name: 'Име на котва',
		errorName: 'Моля въведете име на котвата',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Премахване на котва'
	},
	anchorId: 'По ID на елемент',
	anchorName: 'По име на котва',
	charset: 'Езиков код на свързания ресурс',
	cssClasses: 'CSS класове',
	download: 'Укажи изтегляне',
	displayText: 'Текст за показване',
	emailAddress: 'Имейл aдрес',
	emailBody: 'Съдържание',
	emailSubject: 'Тема',
	id: 'Id',
	info: 'Връзка',
	langCode: 'Езиков код',
	langDir: 'Посока на езика',
	langDirLTR: 'От ляво надясно (LTR)',
	langDirRTL: 'От дясно наляво (RTL)',
	menu: 'Промяна на връзка',
	name: 'Име',
	noAnchors: '(Няма котви в текущия документ)',
	noEmail: 'Моля въведете имейл адрес',
	noUrl: 'Моля въведете URL адрес',
	noTel: 'Please type the phone number', // MISSING
	other: '<друго>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Зависимост (Netscape)',
	popupFeatures: 'Функции на изкачащ прозорец',
	popupFullScreen: 'Цял екран (IE)',
	popupLeft: 'Лява позиция',
	popupLocationBar: 'Лента с локацията',
	popupMenuBar: 'Лента за меню',
	popupResizable: 'Оразмеряем',
	popupScrollBars: 'Ленти за прелистване',
	popupStatusBar: 'Статусна лента',
	popupToolbar: 'Лента с инструменти',
	popupTop: 'Горна позиция',
	rel: 'Свързаност (rel атрибут)',
	selectAnchor: 'Изберете котва',
	styles: 'Стил',
	tabIndex: 'Ред на достъп',
	target: 'Цел',
	targetFrame: '<frame>',
	targetFrameName: 'Име на целевия прозорец',
	targetPopup: '<изкачащ прозорец>',
	targetPopupName: 'Име на изкачащ прозорец',
	title: 'Връзка',
	toAnchor: 'Връзка към котва в текста',
	toEmail: 'Имейл',
	toUrl: 'Уеб адрес',
	toPhone: 'Phone', // MISSING
	toolbar: 'Връзка',
	type: 'Тип на връзката',
	unlink: 'Премахни връзката',
	upload: 'Качване'
} );
